@@ -6,9 +6,10 @@ use common::sense;
 
 use Carp qw(confess);
 use Moose;
-use Net::Curl::Easy;
 
-our $VERSION = '0.006'; # VERSION
+use AnyEvent::Net::Curl::Const;
+
+our $VERSION = '0.007'; # VERSION
 
 
 has stamp       => (is => 'rw', isa => 'Int', default => time);
@@ -30,47 +31,28 @@ has stats       => (
         size_download       => 0,
         size_upload         => 0,
         starttransfer_time  => 0,
-        total               => 0,
         total_time          => 0,
     } },
 );
 
 
-has const_map   => (is => 'rw', isa => 'HashRef[Num]', default => sub { {} });
-
-sub BUILD {
-    my ($self) = @_;
-
-    foreach my $type (keys %{$self->stats}) {
-        next if $type eq 'total';
-
-        eval {
-            no strict 'refs';   ## no critic
-            my $const_name = 'Net::Curl::Easy::CURLINFO_' . uc($type);
-            $self->const_map->{$type} = *$const_name->();
-        };
-        confess "Unable to obtain CURLINFO_\U$type\E value: $@" if $@;
-    }
-}
-
-
 sub sum {
     my ($self, $from) = @_;
 
-    foreach my $type (keys %{$self->stats}) {
-        next if $type eq 'total';
-        my $val = 0;
+    #return 1;
 
-        if ($from->isa('AnyEvent::Net::Curl::Queued::Easy')) {
-            $val = $from->getinfo($self->const_map->{$type});
-        } elsif (ref($from) eq __PACKAGE__) {
-            $val = $from->stats->{$type};
-        }
+    my $is_stats;
+    if ($from->isa('AnyEvent::Net::Curl::Queued::Easy')) {
+        $is_stats = 0;
+    } elsif (ref($from) eq __PACKAGE__) {
+        $is_stats = 1;
+    }
 
-        $self->stats->{$type} += $val;
+    foreach my $type (keys %{$self->stats}) {
+        next if $type eq 'total';
+        $self->stats->{$type} += $is_stats ? $from->stats->{$type} : $from->getinfo(AnyEvent::Net::Curl::Const::info($type));
     }
 
-    ++$self->stats->{total};
     $self->stamp(time);
 
     return 1;
@@ -93,7 +75,7 @@ AnyEvent::Net::Curl::Queued::Stats - Connection statistics for AnyEvent::Net::Cu
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -139,10 +121,6 @@ C<HashRef[Num]> with statistics:
 
 Variable names are from respective L<curl_easy_getinfo()|http://curl.haxx.se/libcurl/c/curl_easy_getinfo.html> accessors.
 
-=head2 const_map
-
-Cache of L<curl_easy_getinfo()|http://curl.haxx.se/libcurl/c/curl_easy_getinfo.html> constants.
-
 =head1 METHODS
 
 =head2 sum($from)
